@@ -119,25 +119,27 @@ static GnomeCanvasItemClass *parent_class;
 GtkType
 gnome_canvas_pixbuf_get_type (void)
 {
-	static GtkType canvas_pixbuf_type = 0;
+	static GType pixbuf_type;
 
-	if (!canvas_pixbuf_type) {
-		static const GtkTypeInfo canvas_pixbuf_info = {
-			"GnomeCanvasPixbuf",
-			sizeof (GnomeCanvasPixbuf),
+	if (!pixbuf_type) {
+		static const GTypeInfo object_info = {
 			sizeof (GnomeCanvasPixbufClass),
-			(GtkClassInitFunc) gnome_canvas_pixbuf_class_init,
-			(GtkObjectInitFunc) gnome_canvas_pixbuf_init,
-			NULL, /* reserved_1 */
-			NULL, /* reserved_2 */
-			(GtkClassInitFunc) NULL
+			(GBaseInitFunc) NULL,
+			(GBaseFinalizeFunc) NULL,
+			(GClassInitFunc) gnome_canvas_pixbuf_class_init,
+			(GClassFinalizeFunc) NULL,
+			NULL,			/* class_data */
+			sizeof (GnomeCanvasPixbuf),
+			0,			/* n_preallocs */
+			(GInstanceInitFunc) gnome_canvas_pixbuf_init,
+			NULL			/* value_table */
 		};
 
-		canvas_pixbuf_type = gtk_type_unique (gnome_canvas_item_get_type (),
-						      &canvas_pixbuf_info);
+		pixbuf_type = g_type_register_static (GNOME_TYPE_CANVAS_ITEM, "GnomeCanvasPixbuf",
+						     &object_info, 0);
 	}
 
-	return canvas_pixbuf_type;
+	return pixbuf_type;
 }
 
 /* Class initialization function for the pixbuf canvas item */
@@ -152,7 +154,7 @@ gnome_canvas_pixbuf_class_init (GnomeCanvasPixbufClass *class)
 	object_class = (GtkObjectClass *) class;
 	item_class = (GnomeCanvasItemClass *) class;
 
-	parent_class = gtk_type_class (gnome_canvas_item_get_type ());
+	parent_class = g_type_class_peek_parent (class);
 
 	gobject_class->set_property = gnome_canvas_pixbuf_set_property;
 	gobject_class->get_property = gnome_canvas_pixbuf_get_property;
@@ -599,13 +601,13 @@ compute_viewport_affine (GnomeCanvasPixbuf *gcp, double *viewport_affine, double
 	case GTK_ANCHOR_N:
 	case GTK_ANCHOR_CENTER:
 	case GTK_ANCHOR_S:
-		ti_len *= (x - (w/ 2));
+		ti_len *= x - w * si_len / 2;
 		break;
 
 	case GTK_ANCHOR_NE:
 	case GTK_ANCHOR_E:
 	case GTK_ANCHOR_SE:
-		ti_len *= (x - w);
+		ti_len *= x - w * si_len;
 		break;
 
         default:
@@ -630,13 +632,13 @@ compute_viewport_affine (GnomeCanvasPixbuf *gcp, double *viewport_affine, double
 	case GTK_ANCHOR_W:
 	case GTK_ANCHOR_CENTER:
 	case GTK_ANCHOR_E:
-		tj_len *= y - (h / 2);
+		tj_len *= y - h * sj_len / 2;
 		break;
 
 	case GTK_ANCHOR_SW:
 	case GTK_ANCHOR_S:
 	case GTK_ANCHOR_SE:
-		tj_len *= y - h;
+		tj_len *= y - h * sj_len;
 		break;
 
         default:
@@ -732,6 +734,12 @@ gnome_canvas_pixbuf_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_
 	if (parent_class->update)
 		(* parent_class->update) (item, affine, clip_path, flags);
 
+        /* the optimzations below cause rarely triggered redrawing bugs and
+	 * don't seem to actually save much performance. so it's probably
+	 * better to turn them off, than to chase subtle optimization bugs
+	 * throughgout all of gnome-canvas-pixbuf.c - TIMJ
+	 */
+#ifdef USE_BROKEN_OPTIMIZATIONS
 	if (((flags & GNOME_CANVAS_UPDATE_VISIBILITY)
 	     && !(GTK_OBJECT_FLAGS (item) & GNOME_CANVAS_ITEM_VISIBLE))
 	    || (flags & GNOME_CANVAS_UPDATE_AFFINE)
@@ -756,6 +764,13 @@ gnome_canvas_pixbuf_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_
 		priv->need_pixbuf_update = FALSE;
 		priv->need_xform_update = FALSE;
 	}
+#else   /* ordinary update logic */
+        gnome_canvas_request_redraw (item->canvas, item->x1, item->y1, item->x2, item->y2);
+        recompute_bounding_box (gcp, affine);
+        gnome_canvas_request_redraw (item->canvas, item->x1, item->y1, item->x2, item->y2);
+        priv->need_pixbuf_update = FALSE;
+        priv->need_xform_update = FALSE;
+#endif
 }
 
 
@@ -901,7 +916,10 @@ gnome_canvas_pixbuf_render (GnomeCanvasItem *item, GnomeCanvasBuf *buf)
         gnome_canvas_buf_ensure_buf (buf);
 
 
-	if (art_affine_rectilinear (render_affine))
+	if ((fabs (render_affine[1]) < GNOME_CANVAS_EPSILON) &&
+	    (fabs (render_affine[2]) < GNOME_CANVAS_EPSILON) &&
+	    render_affine[0] > 0.0 &&
+	    render_affine[3] > 0.0)
 	  {
 	    GdkPixbuf *dest_pixbuf;
 	    int x0, y0, x1, y1;
@@ -940,7 +958,7 @@ gnome_canvas_pixbuf_render (GnomeCanvasItem *item, GnomeCanvasBuf *buf)
 				   render_affine[5] - buf->rect.y0,
 				   render_affine[0],
 				   render_affine[3],
-				   GDK_INTERP_NEAREST,
+				   GDK_INTERP_BILINEAR,
 				   255);
 
 	    gdk_pixbuf_unref (dest_pixbuf);
