@@ -486,7 +486,7 @@ gnome_canvas_shape_set_property (GObject      *object,
 			priv->dash.offset = dash->offset;
 			priv->dash.n_dash = dash->n_dash;
 			if (dash->dash != NULL) {
-				priv->dash.dash = g_new (double, dash->n_dash * sizeof (double));
+				priv->dash.dash = g_new (double, dash->n_dash);
 				memcpy (priv->dash.dash, dash->dash, dash->n_dash * sizeof (double));
 			}
 		}
@@ -629,7 +629,7 @@ gnome_canvas_shape_get_property (GObject     *object,
 		break;
 
 	case PROP_DASH:
-		g_value_set_pointer (value, priv->dash.dash);
+		g_value_set_pointer (value, &priv->dash);
 		break;
 		
 	default:
@@ -1415,7 +1415,7 @@ gcbp_ensure_mask (GnomeCanvasShape * shape, gint width, gint height)
 			ctx->clear_gc = NULL;
 			ctx->xor_gc = NULL;
 
-			g_object_set_data (G_OBJECT (canvas), "BpathDrawContext", ctx);
+			g_object_set_data (G_OBJECT (canvas), "BpathDrawCtx", ctx);
 
 		} else {
 			ctx->refcount++;
