@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * $Id: gnome-canvas-text.c,v 1.83.2.1 2005/05/19 14:10:25 kmaraas Exp $
+ * $Id$
  * Copyright (C) 1997, 1998, 1999, 2000 Free Software Foundation
  * All rights reserved.
  *
@@ -316,7 +316,7 @@ gnome_canvas_text_class_init (GnomeCanvasTextClass *class)
 		 PROP_SIZE,
 		 g_param_spec_int ("size",
 				   _("Font size"),
-				   _("Font size"),
+				   _("Font size (as a multiple of PANGO_SCALE, eg. 12*PANGO_SCALE for a 12pt font size)"),
 				   0,
 				   G_MAXINT,
 				   0,
@@ -327,7 +327,7 @@ gnome_canvas_text_class_init (GnomeCanvasTextClass *class)
 		PROP_SIZE_POINTS,
 		g_param_spec_double ("size_points",
 				     _("Font points"),
-				     _("Font size in points"),
+				     _("Font size in points (eg. 12 for a 12pt font size)"),
 				     0.0,
 				     G_MAXDOUBLE,
 				     0.0,
@@ -1617,13 +1617,12 @@ gnome_canvas_text_point (GnomeCanvasItem *item, double x, double y,
 
 		pango_layout_iter_get_line_extents (iter, NULL, &log_rect);
 				
+		x1 = text->cx + PANGO_PIXELS (log_rect.x);
+		y1 = text->cy + PANGO_PIXELS (log_rect.y);
+		x2 = x1 + PANGO_PIXELS (log_rect.width);
+		y2 = y1 + PANGO_PIXELS (log_rect.height);
+
 		if (text->clip) {
-			x1 = PANGO_PIXELS (log_rect.x);
-			y1 = PANGO_PIXELS (log_rect.y);
-			x2 = PANGO_PIXELS (log_rect.x+log_rect.width);
-			y2 = PANGO_PIXELS (log_rect.y+log_rect.height);
-
-
 			if (x1 < text->clip_cx)
 				x1 = text->clip_cx;
 
@@ -1638,11 +1637,6 @@ gnome_canvas_text_point (GnomeCanvasItem *item, double x, double y,
 
 			if ((x1 >= x2) || (y1 >= y2))
 				continue;
-		} else {
-			x1 = text->x;
-			y1 = text->y;
-			x2 = log_rect.width;
-			y2 = log_rect.height;			
 		}
 
 		/* Calculate distance from point to rectangle */
